@@ -1,6 +1,6 @@
 from abc import ABC
 import hashlib
-from typing import Union
+from typing import Callable, Union
 
 
 class NoID(ABC):
@@ -36,6 +36,18 @@ class Text(Element):
     def __eq__(self, other):
         return self.text == other.text
 
+    def apply(self, *cleaners: Callable):
+        """Applies a cleaning brick to the text element. The function that's passed in
+        should take a string as input and produce a string as output."""
+        cleaned_text = self.text
+        for cleaner in cleaners:
+            cleaned_text = cleaner(cleaned_text)
+
+        if not isinstance(cleaned_text, str):
+            raise ValueError("Cleaner produced a non-string output.")
+
+        self.text = cleaned_text
+
 
 class NarrativeText(Text):
     """NarrativeText is an element consisting of multiple, well-formulated sentences. This
@@ -47,9 +59,11 @@ class NarrativeText(Text):
 
 
 class ListItem(Text):
-    """BulletedText is a NarrativeText element that is part of a bulleted list."""
+    """ListItem is a NarrativeText element that is part of a list."""
 
-    category = "BulletedText"
+    category = "ListItem"
+
+    pass
 
 
 class Title(Text):
